package com.mycompany.commerce.project.facade.server.authorization;

/*
 *-----------------------------------------------------------------
 * IBM Confidential
 *
 * OCO Source Materials
 *
 * WebSphere Commerce
 *
 * (C) Copyright IBM Corp.  2008
 *
 * The source code for this program is not published or otherwise
 * divested of its trade secrets, irrespective of what has
 * been deposited with the U.S. Copyright Office.
 *-----------------------------------------------------------------
 */

import java.rmi.RemoteException;

import com.ibm.commerce.common.objects.StoreAccessBean;
import com.ibm.commerce.registry.StoreRegistry;
import com.ibm.commerce.security.AbstractProtectableProxy;
import com.ibm.commerce.security.Protectable;
import com.mycompany.commerce.project.facade.datatypes.ProjectCollectionType;

/**
 * This class represents a protectable proxy object that is the bridge between
 * any Java object and the policy manager access control engine that is part of
 * WebSphere Commerce.
 */
public class ProjectCollectionTypeProtectableProxy extends
		AbstractProtectableProxy implements Protectable {

	private static final String CLASSNAME = ProjectCollectionTypeProtectableProxy.class
			.getName();

	private static final java.util.logging.Logger LOGGER = com.ibm.commerce.foundation.common.util.logging.LoggingHelper
			.getLogger(ProjectCollectionTypeProtectableProxy.class);

	/**
	 * Creates an instance of the protectable proxy object.
	 */
	public ProjectCollectionTypeProtectableProxy() {
		super();
	}

	/**
	 * This method determines if a given member fulfills a given relationship
	 * with the resource.
	 * 
	 * @param member
	 *            This is the member id of the member.
	 * @param relationship
	 *            This is the relationship the member has with to the resource.
	 * @return This method will always return <code>true</code>.
	 * @exception RemoteException
	 * @exception Exception
	 */
	public boolean fulfills(Long member, String relationship)
			throws RemoteException, Exception {
		final String METHODNAME = "fulfills(Long, String)";
		if (com.ibm.commerce.foundation.common.util.logging.LoggingHelper
				.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.entering(CLASSNAME, METHODNAME);
		}

		if (com.ibm.commerce.foundation.common.util.logging.LoggingHelper
				.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.exiting(CLASSNAME, METHODNAME);
		}

		return super.fulfills(member, relationship);
	}

	/**
	 * This method will return the owner of the protectable object. If the owner
	 * has not been specified on the proxy object, then the owner will be the
	 * owner of the store that can be resolved from the command context.
	 * 
	 * @return The owner of the protectable proxy.
	 * @exception Exception
	 *                A problem occurred while resolving the owner.
	 * @exception RemoteException
	 *                A problem occurred while accessing a remote resource.
	 * @see com.ibm.commerce.security.Protectable#getOwner()
	 */
	public Long getOwner() throws Exception, RemoteException {

		final String METHODNAME = "getOwner()";
		if (com.ibm.commerce.foundation.common.util.logging.LoggingHelper
				.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.entering(CLASSNAME, METHODNAME);
		}

		Long ownerId = null;
		ProjectCollectionType aProjectCollectionType = (ProjectCollectionType) this
				.getObject();
		//		Check if owner id is available in the noun
		if (aProjectCollectionType != null) {

			if (aProjectCollectionType.getProjectCollectionIdentifier() != null
					&& aProjectCollectionType.getProjectCollectionIdentifier()
							.getExternalIdentifier() != null
					&& aProjectCollectionType.getProjectCollectionIdentifier()
							.getExternalIdentifier().getStoreIdentifier() != null
					&& aProjectCollectionType.getProjectCollectionIdentifier()
							.getExternalIdentifier().getStoreIdentifier()
							.getUniqueID() != null) {

				StoreAccessBean aStore = StoreRegistry.singleton().find(
						Integer.valueOf(aProjectCollectionType
								.getProjectCollectionIdentifier()
								.getExternalIdentifier().getStoreIdentifier()
								.getUniqueID()));
				ownerId = aStore.getOwner();
			} else {
				ownerId = super.getOwner();
			}
		} else {
			ownerId = super.getOwner();
		}

		if (com.ibm.commerce.foundation.common.util.logging.LoggingHelper
				.isEntryExitTraceEnabled(LOGGER)) {
			LOGGER.exiting(CLASSNAME, METHODNAME);
		}

		return ownerId;
	}

}
